sklweka package
===============

sklweka\.classifiers module
---------------------------

.. automodule:: sklweka.classifiers
    :members:
    :undoc-members:
    :show-inheritance:

sklweka\.clusters module
------------------------

.. automodule:: sklweka.clusters
    :members:
    :undoc-members:
    :show-inheritance:

sklweka\.dataset module
-----------------------

.. automodule:: sklweka.dataset
    :members:
    :undoc-members:
    :show-inheritance:

sklweka\.preprocessing module
-----------------------------

.. automodule:: sklweka.preprocessing
    :members:
    :undoc-members:
    :show-inheritance:
